@@ -132,7 +132,7 @@ class OstiumSDK:
         # get the price for this trade's asset/feed
         price_data = await self.price.get_latest_price_json(trade_details['pair']['from'], trade_details['pair']['to'])
         self.log(
-            f"\nPrice data: {price_data} (need here bid, mid, ask prices)")
+            f"\nPrice data: {price_data} (contains bid, mid, ask prices among other things)")
         # get the block number
         block_number = self.ostium.get_block_number()
         self.log(f"\nBlock number: {block_number}")
@@ -155,7 +155,7 @@ class OstiumSDK:
 
         currLongOI = Decimal(pair_details['longOI']) / PRECISION_6
         currShortOI = Decimal(pair_details['shortOI']) / PRECISION_6
-        maxOI = Decimal(pair_details['maxOI']) / PRECISION_6 # maxOI is in USD
+        maxOI = Decimal(pair_details['maxOI']) / PRECISION_6  # maxOI is in USD
 
         openInterestMax = max(currLongOI, currShortOI)
         normalizedOiDelta = ((currLongOI - currShortOI).quantize(PRECISION_6, rounding=ROUND_DOWN) / max(
